agentops_mcp_serverのv0.1.0の強化プラン

## 概要
- 現行バージョンでは、セッション・タスクの途中で中断し、新規セッションを開始した際に、AIエージェントがどこまで完了していて、何を作業中だったのかを完全にトラックすることができません。
- 新規セッションでのプロンプトが「続きを/continue」だけで再開できるようにする場合、RDBMSのロールフォワードのような仕組みが必要です。
- 現在、handoff / WIP / session_logという3種のファイルを利用していますが、v0.1.0ではこれらを**廃止**します。
- PostgreSQLのWALを参考に、journal.jsonl（追記専用のイベントログ）、snapshot.json（一定間隔または節目での状態スナップショット）、checkpoint.json（ロールフォワードの開始位置）、という3つのファイルで実装します。
- イベントはAIエージェントの行動から必ず発生し、上記のファイルはMCPサーバが自動的に更新します。
- 実装の前提条件
  - 複数のプロジェクトを同時に作業
  - 各プロジェクトはそれぞれ固有のディレクトリしか使わない
  - プロジェクト毎にMCPサーバは起動する（別プロセス）

## 成果物
- フェーズに分割した実装計画
- 実装計画の各フェーズをタスクに分割したチケット
- 自動的に記録するイベントの具体的な仕様
- journal.jsonl、snapshot.json、checkpoint.jsonのスキーマ

## 修正対象
- zed-agentops-init.sh
- src/agentops_mcp_server/main.py
- handoff / WIP / session_logの廃止に伴い不要となる実装の削除
